pub struct ConfigBinding {
pub source: ConfigSource,
pub tiers: Vec<String>,
pub expansion: BTreeMap<String, Vec<TokenExpansion>>,
}Expand description
Layered config transport. subc stores tiered raw documents and transports literal token references; modules merge and expand them at use time.
Fields
source: ConfigSourcetiers: Vec<String>expansion: BTreeMap<String, Vec<TokenExpansion>>Trait Implementations
Sourceimpl Clone for ConfigBinding
impl Clone for ConfigBinding
Sourcefn clone(&self) -> ConfigBinding
fn clone(&self) -> ConfigBinding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConfigBinding
impl Debug for ConfigBinding
Sourceimpl<'de> Deserialize<'de> for ConfigBinding
impl<'de> Deserialize<'de> for ConfigBinding
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ConfigBinding
impl PartialEq for ConfigBinding
Sourcefn eq(&self, other: &ConfigBinding) -> bool
fn eq(&self, other: &ConfigBinding) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ConfigBinding
impl Serialize for ConfigBinding
impl StructuralPartialEq for ConfigBinding