pub enum ScopeEndOutcome {
Ended,
NotLive,
}Expand description
What scope.apply did with one requested end.
Variants
Ended
The named scope ref was live at this epoch and was ended.
NotLive
The named scope ref was not live at this epoch; this end request changed nothing.