pub struct ModuleManifestBuilder { /* private fields */ }Expand description
Incrementally constructs a ModuleManifest without fabricating absent facts.
Implementations
Sourceimpl ModuleManifestBuilder
impl ModuleManifestBuilder
Sourcepub fn protocol_ver(self, protocol_ver: u8) -> Self
pub fn protocol_ver(self, protocol_ver: u8) -> Self
Overrides the linked protocol version for compatibility fixtures.
Sourcepub fn trust_tier(self, trust_tier: Option<TrustTier>) -> Self
pub fn trust_tier(self, trust_tier: Option<TrustTier>) -> Self
Declares the optional trust tier of this module.
The daemon does not evaluate this field on any production path.
Sourcepub fn provides(self, provides: Vec<ProviderRole>) -> Self
pub fn provides(self, provides: Vec<ProviderRole>) -> Self
Declares the provider roles this module exposes.
Sourcepub fn consumes(self, consumes: Vec<ConsumerRole>) -> Self
pub fn consumes(self, consumes: Vec<ConsumerRole>) -> Self
Declares the consumer roles this module requests.
Sourcepub fn bindings(self, bindings: Option<Bindings>) -> Self
pub fn bindings(self, bindings: Option<Bindings>) -> Self
Declares the optional resource and subsystem bindings of this module.
The daemon does not evaluate this field on any production path.
Sourcepub fn capabilities(self, capabilities: Option<CapabilityDeclarations>) -> Self
pub fn capabilities(self, capabilities: Option<CapabilityDeclarations>) -> Self
Adds optional capability-grammar declarations.
Sourcepub fn self_signals(
self,
self_signals: Option<Vec<SelfSignalDeclaration>>,
) -> Self
pub fn self_signals( self, self_signals: Option<Vec<SelfSignalDeclaration>>, ) -> Self
Adds optional periodic or event-driven behavior declarations.
Sourcepub fn provenance(self, provenance: Option<ManifestProvenance>) -> Self
pub fn provenance(self, provenance: Option<ManifestProvenance>) -> Self
Adds optional build provenance declared by the module.
Sourcepub fn build(self) -> ModuleManifest
pub fn build(self) -> ModuleManifest
Finishes the manifest.